@@ -161,7 +161,7 @@
 //! ### build.rs
 //! **NOTE** - Individual instruction generation can be toggled on or off via [`Config`](crate::Config)
 //! ```
-//! # use anyhow::Result;
+//! use anyhow::Result;
 //! use vergen::{Config, vergen};
 //!
 //! fn main() -> Result<()> {
@@ -213,6 +213,7 @@
         incomplete_features,
         indirect_structural_match,
         inline_no_sanitize,
+        invalid_doc_attributes,
         invalid_value,
         irrefutable_let_patterns,
         keyword_idents,
@@ -292,34 +293,20 @@
     )
 )]
 // nightly only lints
-#![cfg_attr(
-    all(msrv, nightly_lints),
-    deny(
-        non_fmt_panics,
-        rust_2021_incompatible_closure_captures,
-        rust_2021_incompatible_or_patterns,
-        rust_2021_prefixes_incompatible_syntax,
-        rust_2021_prelude_collisions,
-        unsupported_calling_conventions,
-    )
-)]
+// #![cfg_attr(all(msrv, nightly_lints), deny())]
 // nightly or beta only lints
 #![cfg_attr(
     all(msrv, any(beta_lints, nightly_lints)),
-    deny(invalid_doc_attributes)
+    deny(break_with_label_and_loop, deref_into_dyn_supertrait, must_not_suspend,)
 )]
 // beta only lints
-#![cfg_attr(all(msrv, beta_lints), deny(disjoint_capture_migration))]
+// #![cfg_attr(all(msrv, beta_lints), deny())]
 // beta or stable only lints
-#![cfg_attr(
-    all(msrv, any(beta_lints, stable_lints)),
-    deny(non_fmt_panic, or_patterns_back_compat)
-)]
+// #![cfg_attr(all(msrv, any(beta_lints, stable_lints)), deny())]
 // stable only lints
-#![cfg_attr(all(msrv, stable_lints), deny(disjoint_capture_drop_reorder))]
+// #![cfg_attr(all(msrv, stable_lints),deny())]
 // clippy lints
 #![cfg_attr(msrv, deny(clippy::all, clippy::pedantic))]
-#![cfg_attr(all(msrv, nightly_lints), deny(clippy::nonstandard_macro_braces))]
 #![cfg_attr(msrv, allow(clippy::copy_iterator))]
 // rustdoc lints
 #![cfg_attr(msrv, deny(
